using SlnMesnac.Model.domain;
using System;
using System.Collections.Generic;
using System.Text;
using System.Threading.Tasks;

namespace SlnMesnac.Repository.service
{
    public interface ILogoConfigService
    {
        /// <summary>
        /// 模糊查询，从本地查询某个型号
        /// </summary>
        /// <returns></returns>
        Task<List<LogoConfig>> GetLikeByCode(string code);

        /// <summary>
        /// 从MES查询所有型号
        /// </summary>
        /// <returns></returns>
        List<ProductModel> GetMesAllRecord();

        /// <summary>
        /// 根据成品条码从MES查询型号
        /// </summary>
        /// <returns></returns>
        ProductModel GetMaterialTypeByBarCode(string barCode);

        /// <summary>
        /// 从本地查询所有型号用来展示
        /// </summary>
        /// <returns></returns>
        Task<List<LogoConfig>> GetLocalAllRecordAsync();

        /// <summary>
        ///指定型号查询
        /// </summary>
        /// <returns></returns>
        LogoConfig GetByMaterialType(string materialType);

        /// <summary>
        ///指定型号修改是否校验
        /// </summary>
        /// <returns></returns>
        bool updateByMaterialType(LogoConfig record);

        /// <summary>
        /// 批量插入型号
        /// </summary>
        /// <returns></returns>
        Task<bool> InsertListAsync(List<LogoConfig> list);
    }
}
